@@ -475,7 +475,6 @@ void Piclinesegment::draw(frame *f) {
 // Draw this line segment.  Clip the line segment according to the
 // point's coordinates, then put them into the graph.  There are some
 // details to laying out the styles and poltting strings correctly.
-    double lastx, lasty;		// The last point plotted (if any)
     double x,y;				// The current point's coordinates
     double lastcx, lastcy;		// The last point plotted post clipping
     double cx,cy;			// The current point post clipping
@@ -501,9 +500,6 @@ void Piclinesegment::draw(frame *f) {
 	    return;
 	}
     }
-    else {
-	lastx = lasty = 0.0;
-    }
 	
     cx = x;
     cy = y;
